2016 Nova Scotia municipal elections
← 2012 | October 15, 2016 | 2020 →

Municipal and school board elections were held in the Canadian province of Nova Scotia on October 15, 2016. Here is a summary of the mayoral results in the major communities in the province and the council results for the four largest municipalities.

## Amherst

Mayoral candidate[1] | Vote | %
--- | --- | ---
David Kogon | 1,630 | 41.30
George Baker | 682 | 17.28
Wayne Bishop | 538 | 13.63
Dale Fawthrop | 416 | 10.54
Robert Bird | 380 | 9.63
Brian Skabar | 301 | 7.63

## Bridgewater

Mayoral candidate[2] | Vote | %
--- | --- | ---
David Mitchell | 1,348 | 53.28
David Walker (X) | 960 | 37.94
Greg Ritcey | 222 | 8.77

## Cape Breton Regional Municipality

Mayoral candidate[3] | Vote | %
--- | --- | ---
Cecil Clarke (X) | 22,250 | 51.55
Rankin MacSween | 20,911 | 48.45

### Cape Breton Regional Council

Candidate | Vote | %
--- | --- | ---
District 1
Clarence Prince (X) | 1,982 | 49.00
Gordon MacDonald | 1,675 | 41.41
Duke Pero | 388 | 9.59
District 2
Earlene MacMullin | 985 | 23.49
Lloyd Wilkie | 980 | 23.37
Diane Power | 966 | 23.03
Clayton Smith | 663 | 15.81
Bill MacDonald | 465 | 11.09
Wally March | 135 | 3.22
District 3
Blue Marshall | 1,189 | 35.98
Cyril MacDonald | 689 | 20.85
Tom Vickers | 584 | 17.67
Jim Clark | 546 | 16.52
Michael MacNeil | 177 | 5.36
André Desjardins Jr. | 120 | 3.63
District 4
Steve Gillespie | 1,325 | 34.90
Darlene Morrison | 745 | 19.62
Darrell Wilson | 702 | 18.49
Dave LeBlanc | 691 | 18.20
Richard Fogarty | 334 | 8.80
District 5
Eldon MacDonald (X) | 1,530 | 45.63
Tom Wilson | 839 | 25.02
Shawn Lesnick | 408 | 12.17
Nigel Kearns | 313 | 9.33
Nadine Bernard | 263 | 7.84
District 6
Ray Paruch (X) | 2,411 | 66.90
Roberta Lynch | 862 | 23.92
Paul R. Theriault | 331 | 9.18
District 7
Ivan Doncaster (X) | 1,767 | 54.94
Rob MacNeill | 924 | 28.73
Joe Ward | 525 | 16.32
District 8
Amanda McDougall | 1,576 | 50.89
Kevin Saccary (X) | 1,521 | 49.11
District 9
George MacDonald (X) | 1,579 | 45.44
Clarence Routledge | 603 | 17.35
Steven James MacNeil | 575 | 16.55
Seward Bonaparte | 515 | 14.82
Lois MacDougall | 203 | 5.84
District 10
Darren Bruckschwaiger | 2,426 | 55.63
Brian Shaw | 1,266 | 29.03
Dave Wilson | 669 | 15.34
District 11
Kendra Coombes | 2,106 | 55.38
Lowell Cormier (X) | 1,697 | 44.62
District 12
Jim MacLeod (X) | 1,460 | 50.98
Kim Sheppard | 1,181 | 41.24
Tera Camus | 223 | 7.79

## Colchester County

Mayoral candidate[4] | Vote | %
--- | --- | ---
Christine Blair | 3,051 | 53.02
Bob Taylor (X) | 2,703 | 46.98

### Colchester County Municipal Council

Candidate | Vote | %
--- | --- | ---
District 1
Eric Boutlier | Acclaimed
District 2
Bill Masters (X) | 567 | 82.77
Shawn Duffy | 118 | 17.23
District 3
Geoff Stewart (X) | Acclaimed
District 4
Mike Cooper (X) | Acclaimed
District 5
Lloyd Gibbs (X) | Acclaimed
District 6
Karen MacKenzie (X) | Acclaimed
District 7
Michael Gregory (X) | Acclaimed
District 8
Ron Cavanaugh (X) | Acclaimed
District 9
Doug MacInnes (X) | Acclaimed
District 10
Tom Taggart (X) | Acclaimed
District 11
Wade Parker (X) | 416 | 50.79
Tom Burke | 403 | 49.21

### District 9 special election

Held on October 21, 2017.

Council candidate[5] | Vote | %
--- | --- | ---
Bob Pash | 379 | 61.23
Bob White | 240 | 38.77

## Halifax Regional Municipality

Mayoral candidate | Vote | %
--- | --- | ---
Mike Savage (X) | 61,875 | 68.43
Lil MacPherson | 28,543 | 31.57

## Kentville

Mayoral candidate[6] | Vote | %
--- | --- | ---
Sandra Snow | 1,850 | 70.18
Dave Corkum (X) | 786 | 29.82

## Kings County

Kings County will be holding mayoral elections for the first time, in addition to elections for municipal council.[7]

Mayoral candidate[8] | Vote | %
--- | --- | ---
Peter Muttart | 5,683 | 51.09
Dick Killam | 3,268 | 29.38
Rick Ackland | 1,133 | 10.19
Laurie Porter | 1,039 | 9.34

### Kings County Municipal Council

Candidate | Vote | %
--- | --- | ---
District 1
Meg Hodges | 1,006 | 63.43
Michael Embree | 580 | 36.57
District 2
Pauline Raven (X) | 833 | 74.04
Deanna O'Neil | 292 | 25.96
District 3
Brian Hirtle (X) | 1,115 | 72.40
Ray Savage | 425 | 27.60
District 4
Martha Armstrong | 603 | 54.28
Wayne Atwater (X) | 508 | 45.72
District 5
Paul Spicer | 395 | 33.73
Diana Brothers (X) | 303 | 25.88
Jeffery Robar | 238 | 20.32
Ted Palmer | 235 | 20.07
District 6
Bob Best (X) | 750 | 55.60
Sandy Buchan | 599 | 44.40
District 7
Emily Lutz | 810 | 72.26
Hugh Curry | 220 | 19.63
Richard Nickerson | 91 | 8.12
District 8
Jim Winsor (X) | 890 | 73.74
Quentin Hill | 317 | 26.26
District 9
Peter Allen | 698 | 66.48
Dan Sparkman | 352 | 33.52

## District of the Municipality of Lunenburg

Mayoral candidate[9] | Vote | %
--- | --- | ---
Carolyn Bolivar-Getson | 4,256 | 50.92
Tom Lockwood | 4,102 | 49.08

## New Glasgow

Mayoral candidate[10] | Vote | %
--- | --- | ---
Nancy Dicks | 1,796 | 45.42
Henderson Paris | 1,693 | 42.82
Ken Langille | 268 | 6.78
Mark Firth | 197 | 4.98

## Region of Queens Municipality

Mayoral candidate[11] | Vote | %
--- | --- | ---
David Dagley | 1,573 | 48.43
Christopher Clarke (X) | 1,271 | 39.13
Scott Costen | 404 | 12.44

## Truro

Mayoral candidate[12] | Vote | %
--- | --- | ---
Bill Mills (X) | 1,827 | 42.72
Keltie Jones | 1,782 | 41.66
Raymond Tynes | 428 | 10.01
Al McNutt | 240 | 5.61

## Yarmouth (Town)

Mayoral Candidate[13] | Vote | %
--- | --- | ---
Pam Mood (X) | 2,010 | 68.44
Charles A. Crosby | 753 | 25.64
Doris Powell | 174 | 5.92

## References

1. ↑
   "Saltwire | Nova Scotia".
2. ↑ "Town of Bridgewater - CANDIDATES FOR 2016 MUNICIPAL & SCHOOL BOARD ELECTION". Archived from the original on 2016-09-16. Retrieved 2016-09-15.
3. ↑ http://www.cbrm.ns.ca/images/stories/Election_2016/OFFICIAL_List_of_Candidates_Sept_14_2016.pdf
4. ↑ "Candidates - Municipality of the County of Colchester". Archived from the original on 2016-09-26. Retrieved 2016-09-15.
5. ↑ https://www.colchester.ca/election-results
6. ↑ "Archived copy". Archived from the original on 2016-09-19. Retrieved 2016-09-16.`{{cite web}}`: CS1 maint: archived copy as title (link)
7. ↑ "Saltwire | Nova Scotia".
8. ↑ "Archived copy" (PDF). Archived from the original (PDF) on 2016-09-16. Retrieved 2016-09-15.`{{cite web}}`: CS1 maint: archived copy as title (link)
9. ↑ "Archived copy". Archived from the original on 2016-11-01. Retrieved 2016-09-15.`{{cite web}}`: CS1 maint: archived copy as title (link)
10. ↑ "Saltwire | Nova Scotia".
11. ↑ "Archived copy". Archived from the original on 2016-09-24. Retrieved 2016-09-15.`{{cite web}}`: CS1 maint: archived copy as title (link)
12. ↑ "Archived copy". Archived from the original on 2016-09-15. Retrieved 2016-09-15.`{{cite web}}`: CS1 maint: archived copy as title (link)
13. ↑ "Town of Yarmouth - Election Candidates 2016". Archived from the original on 2016-10-28. Retrieved 2016-09-16.

## External links

- Government of Nova Scotia: Municipal elections